require 'rubygems'
require 'bundler/setup'
require 'ostruct'
require 'representable/json'

class Agency < OpenStruct
  attr_accessor :agency_id
  attr_accessor :private_service
  attr_accessor :phone
  attr_accessor :timezone
  attr_accessor :disclaimer
  attr_accessor :name
  attr_accessor :lang
  attr_accessor :url
end

module AgencyRepresenter
  include Representable::JSON
  property :agency_id, as: :id
  property :private_service, as: :privateService
  property :phone
  property :timezone
  property :disclaimer
  property :name
  property :lang
  property :url
end

class ArrivalAndDeparture < OpenStruct
  attr_accessor :route_id
  attr_accessor :route_short_name
  attr_accessor :trip_id
  attr_accessor :trip_headsign
  attr_accessor :stop_id
  attr_accessor :predicted_arrival_time
  attr_accessor :predicted_departure_time
  attr_accessor :scheduled_arrival_time
  attr_accessor :scheduled_departure_time
end

module ArrivalAndDepartureRepresenter
  include Representable::JSON
  property :route_id, as: :routeId
  property :route_short_name, as: :routeShortName
  property :trip_id, as: :tripId
  property :trip_headsign, as: :tripHeadsign
  property :stop_id, as: :stopId
  property :predicted_arrival_time, as: :predictedArrivalTime
  property :predicted_departure_time, as: :predictedDepartureTime
  property :scheduled_arrival_time, as: :scheduledArrivalTime
  property :scheduled_departure_time, as: :scheduledDepartureTime
end

class Route < OpenStruct
  attr_accessor :route_id
  attr_accessor :text_color
  attr_accessor :color
  attr_accessor :description
  attr_accessor :long_name
  attr_accessor :short_name
  attr_accessor :type
  attr_accessor :agency_id
  attr_accessor :url
end

module RouteRepresenter
  include Representable::JSON
  property :route_id, as: :id
  property :text_color, as: :textColor
  property :color
  property :description
  property :long_name, as: :longName
  property :short_name, as: :shortName
  property :type
  property :agency_id, as: :agencyId
  property :url
end

class Stop < OpenStruct
  attr_accessor :stop_id
  attr_accessor :lat
  attr_accessor :lon    
  attr_accessor :direction
  attr_accessor :name
  attr_accessor :code
  attr_accessor :location_type
  attr_accessor :routes
end

module StopRepresenter
  include Representable::JSON
  property :stop_id, as: :id
  property :lat
  property :lon    
  property :direction
  property :name
  property :code
  property :location_type, as: :locationType
  collection :routes, extend: RouteRepresenter, class: Route
end

class ScheduleStopTime < OpenStruct
  attr_accessor :departure_enabled
  attr_accessor :arrival_enabled
  attr_accessor :stop_headsign
  attr_accessor :arrival_time
  attr_accessor :service_id
  attr_accessor :trip_id
  attr_accessor :departure_time
end

module ScheduleStopTimeRepresenter
  include Representable::JSON
  property :departure_enabled, as: :departureEnabled
  property :arrival_enabled, as: :arrivalEnabled
  property :stop_headsign , as: :stopHeadsign
  property :arrival_time, as: :arrivalTime
  property :service_id, as: :serviceId
  property :trip_id, as: :tripId
  property :departure_time, as: :departureTime
end

class StopRouteDirectionSchedule < OpenStruct
  attr_accessor :trip_headsign
  attr_accessor :schedule_frequencies
  attr_accessor :schedule_stop_times
end

module StopRouteDirectionScheduleRepresenter
  include Representable::JSON
  property :trip_headsign, as: :tripHeadsign
  property :schedule_frequencies, as: :scheduleFrequencies
  collection :schedule_stop_times, as: :scheduleStopTimes, extend: ScheduleStopTimeRepresenter, class: ScheduleStopTime
end


class StopRouteSchedule < OpenStruct
  attr_accessor :route_id
  attr_accessor :stop_route_direction_schedules
end

module StopRouteScheduleRepresenter
  include Representable::JSON
  property :route_id, as: :routeId
  collection :stop_route_direction_schedules, as: :stopRouteDirectionSchedules, extend: StopRouteDirectionScheduleRepresenter, class: StopRouteDirectionSchedule
end

class StopSchedule < OpenStruct
  attr_accessor :stop_id
  attr_accessor :stop_route_schedules
end

module StopScheduleRepresenter
  include Representable::JSON
  property :stop_id, as: :stopId
  collection :stop_route_schedules, as: :stopRouteSchedules, extend: StopRouteScheduleRepresenter, class: StopRouteSchedule
end

class Vehicle < OpenStruct
  attr_accessor :vehicle_id
  attr_accessor :last_location_update_time
  attr_accessor :location
  attr_accessor :status
  attr_accessor :last_update_time
  attr_accessor :trip_id
  attr_accessor :trip_status
  attr_accessor :phase
end

module VehicleRepresenter
  include Representable::JSON
  property :vehicle_id, as: :vehicleId
  property :last_location_update_time, as: :lastLocationUpdateTime
  property :location
  property :status
  property :last_update_time, as: :lastUpdateTime
  property :trip_id, as: :tripId
  property :trip_status, as: :tripStatus
  property :phase
end